@@ -1,6 +1,7 @@
 from __future__ import print_function, division
 
 import numpy as np
+from astropy import log as logger
 
 from ..util.functions import FreezableClass, bool2str, str2bool, is_numpy_array
 
@@ -300,7 +301,7 @@ class RunConf(object):
     def _write_raytracing(self, group):
         group.attrs['raytracing'] = bool2str(self.raytracing)
 
-    def set_max_interactions(self, inter_max):
+    def set_max_interactions(self, inter_max, warn=True):
         '''
         Set the maximum number of interactions a photon can have.
 
@@ -311,16 +312,25 @@ class RunConf(object):
             used to prevent photons from getting stuck in very optically
             thick regions, especially if the modified random walk is not
             used.
+        warn : bool, optional
+            Whether to emit a warning whenever photons are killed for exceeding
+            the maximum number of iterations.
         '''
         self.n_inter_max = inter_max
+        self.n_inter_max_warn = warn
 
     def _read_max_interactions(self, group):
         self.n_inter_max = group.attrs['n_inter_max']
+        if 'n_inter_max_warn' in group.attrs:
+            self.n_inter_max_warn = str2bool(group.attrs['n_inter_max_warn'])
+        else:
+            self.n_inter_max_warn = True
 
     def _write_max_interactions(self, group):
         group.attrs['n_inter_max'] = self.n_inter_max
+        group.attrs['n_inter_max_warn'] = bool2str(self.n_inter_max_warn)
 
-    def set_max_reabsorptions(self, reabs_max):
+    def set_max_reabsorptions(self, reabs_max, warn=True):
         '''
         Set the maximum number of successive reabsorptions by a source that a
         photon can have.
@@ -329,14 +339,23 @@ class RunConf(object):
         ----------
         reabs_max : int
             Maximum number of reabsorptions for a single photon.
+        warn : bool, optional
+            Whether to emit a warning whenever photons are killed for exceeding
+            the maximum number of reabsorptions.
         '''
         self.n_reabs_max = reabs_max
+        self.n_reabs_max_warn = warn
 
     def _read_max_reabsorptions(self, group):
         self.n_reabs_max = group.attrs['n_reabs_max']
+        if 'n_reabs_max_warn' in group.attrs:
+            self.n_reabs_max_warn = str2bool(group.attrs['n_reabs_max_warn'])
+        else:
+            self.n_reabs_max_warn = True
 
     def _write_max_reabsorptions(self, group):
         group.attrs['n_reabs_max'] = self.n_reabs_max
+        group.attrs['n_reabs_max_warn'] = bool2str(self.n_reabs_max_warn)
 
     def set_pda(self, pda):
         '''
@@ -364,7 +383,7 @@ class RunConf(object):
     def _write_pda(self, group):
         group.attrs['pda'] = bool2str(self.pda)
 
-    def set_mrw(self, mrw, gamma=1.0, inter_max=1000):
+    def set_mrw(self, mrw, gamma=1.0, inter_max=1000, warn=True):
         '''
         Set whether to use the Modified Random Walk (MRW) approximation
 
@@ -385,6 +404,9 @@ class RunConf(object):
             This can be used to prevent photons from getting stuck in the
             corners of cells in very optically thick regions, where the MRW
             stars to become inefficient itself.
+        warn : bool, optional
+            Whether to emit a warning whenever photons are killed for exceeding
+            the maximum number of mrw steps.
 
         References
         ----------
@@ -393,18 +415,24 @@ class RunConf(object):
         self.mrw = mrw
         self.mrw_gamma = gamma
         self.n_inter_mrw_max = inter_max
+        self.n_inter_mrw_max_warn = warn
 
     def _read_mrw(self, group):
         self.mrw = str2bool(group.attrs['mrw'])
         if self.mrw:
             self.mrw_gamma = group.attrs['mrw_gamma']
             self.n_inter_mrw_max = group.attrs['n_inter_mrw_max']
+            if 'n_inter_mrw_max_warn' in group.attrs:
+                self.n_inter_mrw_max_warn = str2bool(group.attrs['n_inter_mrw_max_warn'])
+            else:
+                self.n_inter_mrw_max_warn = True
 
     def _write_mrw(self, group):
         group.attrs['mrw'] = bool2str(self.mrw)
         if self.mrw:
             group.attrs['mrw_gamma'] = self.mrw_gamma
             group.attrs['n_inter_mrw_max'] = self.n_inter_mrw_max
+            group.attrs['n_inter_mrw_max_warn'] = bool2str(self.n_inter_mrw_max_warn)
 
     def set_convergence(self, convergence, percentile=100., absolute=0., relative=0.):
         '''
@@ -643,13 +671,20 @@ class ImageConf(FreezableClass):
         if self.image:
             self.n_x = self.n_y = None
             self.xmin = self.xmax = self.ymin = self.ymax = None
-        self.n_wav = self.wav_min = self.wav_max = None
+        self.n_wav = None
+        self.wav_min = None
+        self.wav_max = None
+        self.iwav_min = None
+        self.iwav_max = None
         self.set_output_bytes(8)
         self.set_track_origin('no')
         self.set_uncertainties(False)
-        self._monochromatic = False
+        self.set_stokes(False)
+        self._set_monochromatic(False)
         self._freeze()
 
+
+
     def set_output_bytes(self, io_bytes):
         '''
         Set whether to output images/SEDs in 32-bit or 64-bit.
@@ -726,7 +761,7 @@ class ImageConf(FreezableClass):
 
     def set_aperture_range(self, n_ap, ap_min, ap_max):
         '''
-        Set the range of apertures to use for SEDs
+        Set the range of apertures to use for SEDs/Images
 
         Parameters
         ----------
@@ -751,48 +786,98 @@ class ImageConf(FreezableClass):
         group.attrs['ap_min'] = self.ap_min
         group.attrs['ap_max'] = self.ap_max
 
+    def _set_monochromatic(self, monochromatic, frequencies=None):
+        """
+        Set whether the images are being computed in monochromatic mode.
+
+        This is not meant to be used directly by users.
+        """
+
+        self._monochromatic = monochromatic
+
+        if monochromatic:
+            if self.n_wav is not None or self.wav_min is not None or self.wav_max is not None:
+                logger.warn("Removing non-monochromatic wavelength_rate settings")
+                self.n_wav = None
+                self.wav_min = None
+                self.wav_max = None
+            self.set_wavelength_index_range(1, len(frequencies))
+        else:
+            if self.iwav_min is not None or self.iwav_max is not None:
+                log.warn("Removing monochromatic wavelength_rate settings")
+                self.iwav_min = None
+                self.iwav_max = None
+
+    def _read_monochromatic(self, group):
+        self._monochromatic = str2bool(group.attrs['monochromatic'])
+
+    def _write_monochromatic(self, group):
+        group.attrs['monochromatic'] = bool2str(self._monochromatic)
+
     def set_wavelength_range(self, n_wav, wav_min, wav_max):
         '''
-        Set the range of wavelengths to use for SEDs
+        Set the range of wavelengths to use for SEDs/Images
 
         Parameters
         ----------
         n_wav : int
-            The number of wavelengths to compute SEDs for
+            The number of wavelengths to compute SEDs/Images for
         wav_min, wav_max : float
             The smallest and largest wavelength to use, in microns
         '''
         if type(n_wav) is not int:
             raise Exception("n_wav should be an integer")
+        if self._monochromatic:
+            raise Exception("set_wavelength_range cannot be used in monochromatic mode")
         self.n_wav = n_wav
         self.wav_min = wav_min
         self.wav_max = wav_max
 
     def _read_wavelength_range(self, group):
-
         self.n_wav = group.attrs['n_wav']
-
-        if 'inu_min' in group.attrs:
-            self.wav_min = group.attrs['inu_min']
-            self.wav_max = group.attrs['inu_max']
-        else:
-            self.wav_min = group.attrs['wav_min']
-            self.wav_max = group.attrs['wav_max']
+        self.wav_min = group.attrs['wav_min']
+        self.wav_max = group.attrs['wav_max']
 
     def _write_wavelength_range(self, group):
-
         if self.n_wav is None:
             raise Exception("Wavelength range has not been set")
         group.attrs['n_wav'] = self.n_wav
+        if self.wav_min is None:
+            raise Exception("Wavelength minimum has not been set")
+        group.attrs['wav_min'] = self.wav_min
+        if self.wav_max is None:
+            raise Exception("Wavelength maximum has not been set")
+        group.attrs['wav_max'] = self.wav_max
 
-        if self._monochromatic:
-            if not type(self.wav_min) is int or not type(self.wav_max) is int:
-                raise Exception("In monochromatic mode, wavelength range should be given as integers")
-            group.attrs['inu_min'] = self.wav_min
-            group.attrs['inu_max'] = self.wav_max
-        else:
-            group.attrs['wav_min'] = self.wav_min
-            group.attrs['wav_max'] = self.wav_max
+    def set_wavelength_index_range(self, iwav_min, iwav_max):
+        '''
+        Set the range of wavelengths to use for SEDs/Images
+
+        This is intended to be used when the monochromatic option is turned on.
+
+        Parameters
+        ----------
+        iwav_min, iwav_max : int
+            The index of the first and last frequency to compute SEDs/Images
+            for. This is the index in the array of wavelengths used when
+            calling ``set_monochromatic``.
+        '''
+        if not self._monochromatic:
+            raise Exception("set_frequency_index_range cannot be used when not in monochromatic mode")
+        self.iwav_min = iwav_min
+        self.iwav_max = iwav_max
+
+    def _read_wavelength_index_range(self, group):
+        # For backward-compability reasons, the variables are called ``inu``
+        # instead of ``iwav`` in the HDF5 files, but these are variable names
+        # the user will never be exposed to.
+        self.iwav_min = group.attrs['inu_min']
+        self.iwav_max = group.attrs['inu_max']
+
+    def _write_wavelength_index_range(self, group):
+        group.attrs['n_wav'] = self.iwav_max - self.iwav_min + 1
+        group.attrs['inu_min'] = self.iwav_min
+        group.attrs['inu_max'] = self.iwav_max
 
     def set_track_origin(self, track_origin):
         '''
@@ -852,6 +937,28 @@ class ImageConf(FreezableClass):
     def _write_uncertainties(self, group):
         group.attrs['uncertainties'] = bool2str(self.uncertainties)
 
+    def set_stokes(self, stokes):
+        '''
+        Set whether to save the full Stokes vector for the images/SEDs.
+
+        If set to `False`, only the I component is saved.
+
+        Parameters
+        ----------
+        stokes : bool
+            Whether to save the full Stokes vector for the images/SEDs.
+        '''
+        self.stokes = stokes
+
+    def _read_stokes(self, group):
+        if 'compute_stokes' in group.attrs:
+            self.stokes = str2bool(group.attrs['compute_stokes'])
+        else:
+            self.stokes = True
+
+    def _write_stokes(self, group):
+        group.attrs['compute_stokes'] = bool2str(self.stokes)
+
     @classmethod
     def read(cls, group):
         self = cls()
@@ -877,10 +984,15 @@ class ImageConf(FreezableClass):
         if self.image:
             self._read_image_size(group)
             self._read_image_limits(group)
-        self._read_wavelength_range(group)
+        self._read_monochromatic(group)
+        if self._monochromatic:
+            self._read_wavelength_index_range(group)
+        else:
+            self._read_wavelength_range(group)
         self._read_output_bytes(group)
         self._read_track_origin(group)
         self._read_uncertainties(group)
+        self._read_stokes(group)
 
     def _write_main_info(self, group):
         group.attrs['compute_sed'] = bool2str(self.sed)
@@ -890,10 +1002,15 @@ class ImageConf(FreezableClass):
         if self.image:
             self._write_image_size(group)
             self._write_image_limits(group)
-        self._write_wavelength_range(group)
+        self._write_monochromatic(group)
+        if self._monochromatic:
+            self._write_wavelength_index_range(group)
+        else:
+            self._write_wavelength_range(group)
         self._write_output_bytes(group)
         self._write_track_origin(group)
         self._write_uncertainties(group)
+        self._write_stokes(group)
 
 
 class BinnedImageConf(ImageConf):
@@ -951,7 +1068,7 @@ class PeeledImageConf(ImageConf):
             The viewing angles to compute SEDs for.
 
         Examples
-        -------
+        --------
 
         Set viewing angles using lists of well-defined angles:
 
