@@ -136,6 +136,9 @@ class ModelOutput(FreezableClass):
                 * 'linpol':  Total linear polarization fraction
                 * 'circpol': Total circular polariation fraction
 
+            Note that if the SED was set up with ``set_stokes(False)``, then
+            only the ``I`` component is available.
+
         technique : str, optional
             Whether to retrieve SED(s) computed with photon peeling-off
             ('peeled') or binning ('binned'). Default is 'peeled'.
@@ -224,7 +227,7 @@ class ModelOutput(FreezableClass):
         '''
 
         # Check argument types
-        if type(stokes) is not str:
+        if not isinstance(stokes, basestring):
             raise ValueError("stokes argument should be a string")
 
         # Check for inconsistent parameters
@@ -425,6 +428,9 @@ class ModelOutput(FreezableClass):
 
         # Select correct Stokes component
 
+        if flux.shape[0] == 1 and stokes != 'I':
+            raise ValueError("Only the Stokes I value was stored for this SED")
+
         if stokes in STOKESD:
             flux = flux[STOKESD[stokes]]
             if uncertainties:
@@ -482,6 +488,9 @@ class ModelOutput(FreezableClass):
                 * 'linpol':  Total linear polarization fraction
                 * 'circpol': Total circular polariation fraction
 
+            Note that if the image was set up with ``set_stokes(False)``, then
+            only the ``I`` component is available.
+
         technique : str, optional
             Whether to retrieve an image computed with photon peeling-off
             ('peeled') or binning ('binned'). Default is 'peeled'.
@@ -567,7 +576,7 @@ class ModelOutput(FreezableClass):
         '''
 
         # Check argument types
-        if type(stokes) is not str:
+        if not isinstance(stokes, basestring):
             raise ValueError("stokes argument should be a string")
 
         # Check for inconsistent parameters
@@ -825,6 +834,9 @@ class ModelOutput(FreezableClass):
 
         # Select correct Stokes component
 
+        if flux.shape[0] == 1 and stokes != 'I':
+            raise ValueError("Only the Stokes I value was stored for this image")
+
         if stokes in STOKESD:
             flux = flux[STOKESD[stokes]]
             if uncertainties:
@@ -922,14 +934,12 @@ class ModelOutput(FreezableClass):
 
         Returns
         -------
-
         grid : Grid instance
             An object containing information about the geometry and quantities
         '''
 
         from .helpers import find_last_iteration
 
-
         if self.file['Input'].file != self.file.file:
             # Workaround for h5py bug - can't access link directly,
             # need to use file attribute
